@@ -520,7 +520,7 @@ class Action(MethodsInterface):
         args = []
         arg_count = func_condition.func_code.co_argcount
         for param_name in func_condition.func_code.co_varnames[:arg_count]:
-            if param_name in ('Get', 'Select', 'ZipVars'):
+            if param_name in ('Get', 'GetBool', 'Select', 'ZipVars'):
                 args.append(getattr(self.clVars, param_name))
             elif param_name == 'eachvar':
                 args.append(self.eachvar)
